/*
 * libhfs - library for reading and writing Macintosh HFS volumes
 * Copyright (C) 1996-1998 Robert Leslie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: version.c,v 1.10 1998/02/19 20:16:27 rob Exp $
 */

# include "version.h"

char libhfs_rcsid[] =
  "$Id: version.c,v 1.10 1998/02/19 20:16:27 rob Exp $";

char libhfs_version[]   = "libhfs version 3.2";
char libhfs_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
char libhfs_author[]    = "Robert Leslie <rob@mars.org>";
